@@ -37,6 +37,7 @@ const char *vaProfileStr(VAProfile profile)
         TOSTR(VAProfileMPEG4Main);
         TOSTR(VAProfileH264Main);
         TOSTR(VAProfileH264High);
+        TOSTR(VAProfileH264High10);
         TOSTR(VAProfileVC1Simple);
         TOSTR(VAProfileVC1Main);
         TOSTR(VAProfileVC1Advanced);
@@ -65,6 +66,8 @@ const char *vaProfileStr(VAProfile profile)
         TOSTR(VAProfileAV1Profile1);
         TOSTR(VAProfileHEVCSccMain444_10);
         TOSTR(VAProfileProtected);
+        TOSTR(VAProfileVVCMain10);
+        TOSTR(VAProfileVVCMultilayerMain10);
     default:
         break;
     }
@@ -148,6 +151,8 @@ const char *vaConfigAttribTypeStr(VAConfigAttribType configAttribType)
         TOSTR(VAConfigAttribEncAV1Ext1);
         TOSTR(VAConfigAttribEncAV1Ext2);
         TOSTR(VAConfigAttribEncPerBlockControl);
+        TOSTR(VAConfigAttribEncMaxTileRows);
+        TOSTR(VAConfigAttribEncMaxTileCols);
     case VAConfigAttribTypeMax:
         break;
     }
@@ -202,6 +207,11 @@ const char *vaBufferTypeStr(VABufferType bufferType)
         TOSTR(VAProtectedSessionExecuteBufferType);
         TOSTR(VAEncryptionParameterBufferType);
         TOSTR(VAEncDeltaQpPerBlockBufferType);
+        TOSTR(VAAlfBufferType);
+        TOSTR(VALmcsBufferType);
+        TOSTR(VASubPicBufferType);
+        TOSTR(VATileBufferType);
+        TOSTR(VASliceStructBufferType);
     case VABufferTypeMax:
         break;
     }
